==> ruff-0.8.2.tar.gz: ruff-0.8.2/crates/ruff_linter/src/rules/pyupgrade/rules/mod.rs <==
pub(crate) use convert_named_tuple_functional_to_class::*;
pub(crate) use convert_typed_dict_functional_to_class::*;
pub(crate) use datetime_utc_alias::*;
pub(crate) use deprecated_c_element_tree::*;
pub(crate) use deprecated_import::*;
pub(crate) use deprecated_mock_import::*;
pub(crate) use deprecated_unittest_alias::*;
pub(crate) use extraneous_parentheses::*;
pub(crate) use f_strings::*;
pub(crate) use format_literals::*;
pub(crate) use lru_cache_with_maxsize_none::*;
pub(crate) use lru_cache_without_parameters::*;
pub(crate) use native_literals::*;
pub(crate) use open_alias::*;
pub(crate) use os_error_alias::*;
pub(crate) use outdated_version_block::*;
pub(crate) use printf_string_formatting::*;
pub(crate) use quoted_annotation::*;
pub(crate) use redundant_open_modes::*;
pub(crate) use replace_stdout_stderr::*;
pub(crate) use replace_str_enum::*;
pub(crate) use replace_universal_newlines::*;
pub(crate) use super_call_with_parameters::*;
pub(crate) use timeout_error_alias::*;
pub(crate) use type_of_primitive::*;
pub(crate) use typing_text_str_alias::*;
pub(crate) use unicode_kind_prefix::*;
pub(crate) use unnecessary_builtin_import::*;
pub(crate) use unnecessary_class_parentheses::*;
pub(crate) use unnecessary_coding_comment::*;
pub(crate) use unnecessary_default_type_args::*;
pub(crate) use unnecessary_encode_utf8::*;
pub(crate) use unnecessary_future_import::*;
pub(crate) use unpacked_list_comprehension::*;
pub(crate) use use_pep585_annotation::*;
pub(crate) use use_pep604_annotation::*;
pub(crate) use use_pep604_isinstance::*;
pub(crate) use use_pep646_unpack::*;
pub(crate) use use_pep695_type_alias::*;
pub(crate) use useless_metaclass_type::*;
pub(crate) use useless_object_inheritance::*;
pub(crate) use yield_in_for_loop::*;

mod convert_named_tuple_functional_to_class;
mod convert_typed_dict_functional_to_class;
mod datetime_utc_alias;
mod deprecated_c_element_tree;
mod deprecated_import;
mod deprecated_mock_import;
mod deprecated_unittest_alias;
mod extraneous_parentheses;
mod f_strings;
mod format_literals;
mod lru_cache_with_maxsize_none;
mod lru_cache_without_parameters;
mod native_literals;
mod open_alias;
mod os_error_alias;
mod outdated_version_block;
mod printf_string_formatting;
mod quoted_annotation;
mod redundant_open_modes;
mod replace_stdout_stderr;
mod replace_str_enum;
mod replace_universal_newlines;
mod super_call_with_parameters;
mod timeout_error_alias;
mod type_of_primitive;
mod typing_text_str_alias;
mod unicode_kind_prefix;
mod unnecessary_builtin_import;
mod unnecessary_class_parentheses;
mod unnecessary_coding_comment;
mod unnecessary_default_type_args;
mod unnecessary_encode_utf8;
mod unnecessary_future_import;
mod unpacked_list_comprehension;
mod use_pep585_annotation;
mod use_pep604_annotation;
mod use_pep604_isinstance;
mod use_pep646_unpack;
mod use_pep695_type_alias;
mod useless_metaclass_type;
mod useless_object_inheritance;
mod yield_in_for_loop;

==> ruff-0.9.6.tar.gz: ruff-0.9.6/crates/ruff_linter/src/rules/pyupgrade/rules/mod.rs <==
pub(crate) use convert_named_tuple_functional_to_class::*;
pub(crate) use convert_typed_dict_functional_to_class::*;
pub(crate) use datetime_utc_alias::*;
pub(crate) use deprecated_c_element_tree::*;
pub(crate) use deprecated_import::*;
pub(crate) use deprecated_mock_import::*;
pub(crate) use deprecated_unittest_alias::*;
pub(crate) use extraneous_parentheses::*;
pub(crate) use f_strings::*;
pub(crate) use format_literals::*;
pub(crate) use lru_cache_with_maxsize_none::*;
pub(crate) use lru_cache_without_parameters::*;
pub(crate) use native_literals::*;
pub(crate) use open_alias::*;
pub(crate) use os_error_alias::*;
pub(crate) use outdated_version_block::*;
pub(crate) use pep695::*;
pub(crate) use printf_string_formatting::*;
pub(crate) use quoted_annotation::*;
pub(crate) use redundant_open_modes::*;
pub(crate) use replace_stdout_stderr::*;
pub(crate) use replace_str_enum::*;
pub(crate) use replace_universal_newlines::*;
pub(crate) use super_call_with_parameters::*;
pub(crate) use timeout_error_alias::*;
pub(crate) use type_of_primitive::*;
pub(crate) use typing_text_str_alias::*;
pub(crate) use unicode_kind_prefix::*;
pub(crate) use unnecessary_builtin_import::*;
pub(crate) use unnecessary_class_parentheses::*;
pub(crate) use unnecessary_coding_comment::*;
pub(crate) use unnecessary_default_type_args::*;
pub(crate) use unnecessary_encode_utf8::*;
pub(crate) use unnecessary_future_import::*;
pub(crate) use unpacked_list_comprehension::*;
pub(crate) use use_pep585_annotation::*;
pub(crate) use use_pep604_annotation::*;
pub(crate) use use_pep604_isinstance::*;
pub(crate) use use_pep646_unpack::*;
pub(crate) use useless_metaclass_type::*;
pub(crate) use useless_object_inheritance::*;
pub(crate) use yield_in_for_loop::*;

mod convert_named_tuple_functional_to_class;
mod convert_typed_dict_functional_to_class;
mod datetime_utc_alias;
mod deprecated_c_element_tree;
mod deprecated_import;
mod deprecated_mock_import;
mod deprecated_unittest_alias;
mod extraneous_parentheses;
mod f_strings;
mod format_literals;
mod lru_cache_with_maxsize_none;
mod lru_cache_without_parameters;
mod native_literals;
mod open_alias;
mod os_error_alias;
mod outdated_version_block;
pub(crate) mod pep695;
mod printf_string_formatting;
mod quoted_annotation;
mod redundant_open_modes;
mod replace_stdout_stderr;
mod replace_str_enum;
mod replace_universal_newlines;
mod super_call_with_parameters;
mod timeout_error_alias;
mod type_of_primitive;
mod typing_text_str_alias;
mod unicode_kind_prefix;
mod unnecessary_builtin_import;
mod unnecessary_class_parentheses;
mod unnecessary_coding_comment;
mod unnecessary_default_type_args;
mod unnecessary_encode_utf8;
mod unnecessary_future_import;
mod unpacked_list_comprehension;
mod use_pep585_annotation;
mod use_pep604_annotation;
mod use_pep604_isinstance;
mod use_pep646_unpack;
mod useless_metaclass_type;
mod useless_object_inheritance;
mod yield_in_for_loop;
